==> biostime-openapi-sdk-1.2.1.RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/terminal/TerminalGetValidPromoterAndTerminalAllReqBean.java <==
package global.hh.openapi.sdk.api.bean.terminal;


/**
 * @description: 获取全量有效促销员与终端关系
 * @author: 777771
 * @date: 2021-50-29 15:50:54
 */
public class TerminalGetValidPromoterAndTerminalAllReqBean {
    /**
     * 响应编码 默认100 100：成功，101：失败 102：异常
     */
    private Long code;

    /**
     * 响应描述
     */
    private String desc;

    /**
     * 查询列表项集合
     */
    private Object items;

    /**
     * 当前页
     */
    private Long page;

    /**
     * 每页条数
     */
    private Long pageSize;

    /**
     * 总条数
     */
    private Long total;

    /**
     * 总页数
     */
    private Long totalPage;

    public TerminalGetValidPromoterAndTerminalAllReqBean(){
    }

    public TerminalGetValidPromoterAndTerminalAllReqBean(Long code,String desc,Object items,Long page,Long pageSize,Long total,Long totalPage){
        this.code=code;
        this.desc=desc;
        this.items=items;
        this.page=page;
        this.pageSize=pageSize;
        this.total=total;
        this.totalPage=totalPage;
    }

    private Long getCode() {
        return code;
    }

    private void setCode(Long code) {
        this.code = code;
    }
    private String getDesc() {
        return desc;
    }

    private void setDesc(String desc) {
        this.desc = desc;
    }
    private Object getItems() {
        return items;
    }

    private void setItems(Object items) {
        this.items = items;
    }
    private Long getPage() {
        return page;
    }

    private void setPage(Long page) {
        this.page = page;
    }
    private Long getPageSize() {
        return pageSize;
    }

    private void setPageSize(Long pageSize) {
        this.pageSize = pageSize;
    }
    private Long getTotal() {
        return total;
    }

    private void setTotal(Long total) {
        this.total = total;
    }
    private Long getTotalPage() {
        return totalPage;
    }

    private void setTotalPage(Long totalPage) {
        this.totalPage = totalPage;
    }
}

==> biostime-openapi-sdk-1.5.9.2-RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/terminal/TerminalGetValidPromoterAndTerminalAllReqBean.java <==
package global.hh.openapi.sdk.api.bean.terminal;


/**
 * @description: 获取全量有效促销员与终端关系
 * @author: 13258
 * @date: 2021-03-29 16:03:56
 */
public class TerminalGetValidPromoterAndTerminalAllReqBean {
    /**
     * 响应编码 默认100 100：成功，101：失败 102：异常
     */
    private Long code;

    /**
     * 响应描述
     */
    private String desc;

    /**
     * 查询列表项集合
     */
    private Object items;

    /**
     * 当前页
     */
    private Long page;

    /**
     * 每页条数
     */
    private Long pageSize;

    /**
     * 总条数
     */
    private Long total;

    /**
     * 总页数
     */
    private Long totalPage;

    public TerminalGetValidPromoterAndTerminalAllReqBean(){
    }

    public TerminalGetValidPromoterAndTerminalAllReqBean(Long code,String desc,Object items,Long page,Long pageSize,Long total,Long totalPage){
        this.code=code;
        this.desc=desc;
        this.items=items;
        this.page=page;
        this.pageSize=pageSize;
        this.total=total;
        this.totalPage=totalPage;
    }

    public Long getCode() {
        return code;
    }

    public void setCode(Long code) {
        this.code = code;
    }
    public String getDesc() {
        return desc;
    }

    public void setDesc(String desc) {
        this.desc = desc;
    }
    public Object getItems() {
        return items;
    }

    public void setItems(Object items) {
        this.items = items;
    }
    public Long getPage() {
        return page;
    }

    public void setPage(Long page) {
        this.page = page;
    }
    public Long getPageSize() {
        return pageSize;
    }

    public void setPageSize(Long pageSize) {
        this.pageSize = pageSize;
    }
    public Long getTotal() {
        return total;
    }

    public void setTotal(Long total) {
        this.total = total;
    }
    public Long getTotalPage() {
        return totalPage;
    }

    public void setTotalPage(Long totalPage) {
        this.totalPage = totalPage;
    }
}
